# -*- coding: utf-8 -*-

from demo import config


def pro():
    """
    for production
    :return:
    """
    return {}


def dev():
    """
    for development
    :return:
    """
    return {}


def ci():
    """
    for Continuous integration
    :return:
    """

    return {}


